@@ -142,10 +142,6 @@ typedef struct type_session {
 	mbedtls_ssl_context rproxy_ssl;
 #endif
 #endif
-
-#ifdef ENABLE_HTTP2
-	bool            use_http2;
-#endif
 } t_session;
 
 void init_session(t_session *session);
